@@ -9,11 +9,13 @@
 #endif
 
 addToLibrary({
+  // In -sAUDIO_WORKLET builds, TextDecoder will not exist in AudioWorkletGlobalScope,
+  // so we cannot try to unconditionally initialize it in that build mode.
+#if TEXTDECODER == 2 && !AUDIO_WORKLET
   // TextDecoder constructor defaults to UTF-8
-#if TEXTDECODER == 2
   $UTF8Decoder: "new TextDecoder()",
 #else
-  $UTF8Decoder: "typeof TextDecoder != 'undefined' ? new TextDecoder() : undefined",
+  $UTF8Decoder: "globalThis.TextDecoder && new TextDecoder()",
 #endif
 
   $findStringEnd: (heapOrArray, idx, maxBytesToRead, ignoreNul) => {
@@ -302,7 +304,7 @@ addToLibrary({
 #if TEXTDECODER == 2
   $UTF16Decoder: "new TextDecoder('utf-16le');",
 #else
-  $UTF16Decoder: "typeof TextDecoder != 'undefined' ? new TextDecoder('utf-16le') : undefined;",
+  $UTF16Decoder: "globalThis.TextDecoder ? new TextDecoder('utf-16le') : undefined;",
 #endif
 
   // Given a pointer 'ptr' to a null-terminated UTF16LE-encoded string in the
